Struct WpCursorShapeManagerV1
pub struct WpCursorShapeManagerV1 { /* private fields */ }wayland and Linux only.Expand description
cursor shape manager
This global offers an alternative, optional way to set cursor images. This new way uses enumerated cursors instead of a wl_surface like wl_pointer.set_cursor does.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
This interface has no events.
Implementations
impl WpCursorShapeManagerV1
impl WpCursorShapeManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the manager
Destroy the cursor shape manager.
pub fn get_pointer<U, D>(
&self,
pointer: &WlPointer,
qh: &QueueHandle<D>,
udata: U,
) -> WpCursorShapeDeviceV1
pub fn get_pointer<U, D>( &self, pointer: &WlPointer, qh: &QueueHandle<D>, udata: U, ) -> WpCursorShapeDeviceV1
manage the cursor shape of a pointer device
Obtain a wp_cursor_shape_device_v1 for a wl_pointer object.
When the pointer capability is removed from the wl_seat, the wp_cursor_shape_device_v1 object becomes inert.
pub fn get_tablet_tool_v2<U, D>(
&self,
tablet_tool: &ZwpTabletToolV2,
qh: &QueueHandle<D>,
udata: U,
) -> WpCursorShapeDeviceV1
pub fn get_tablet_tool_v2<U, D>( &self, tablet_tool: &ZwpTabletToolV2, qh: &QueueHandle<D>, udata: U, ) -> WpCursorShapeDeviceV1
manage the cursor shape of a tablet tool device
Obtain a wp_cursor_shape_device_v1 for a zwp_tablet_tool_v2 object.
When the zwp_tablet_tool_v2 is removed, the wp_cursor_shape_device_v1 object becomes inert.